@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2011 Rocky Bernstein <rockbcpan.org>
+# Copyright (C) 2011-2012 Rocky Bernstein <rockbcpan.org>
 
 use warnings; no warnings 'redefine'; no warnings 'once';
 use rlib '../../../../..';
@@ -12,14 +12,17 @@ use Devel::Trepan::CmdProcessor::Command::Subcmd::Core;
 use vars @Devel::Trepan::CmdProcessor::Command::Subcmd::SUBCMD_VARS;
 
 use constant MAX_ARGS => undef;  # Need at most this many - undef -> unlimited.
-our $CMD = "info watch";
-our $HELP         = <<"EOH";
-${CMD} [WATCHPOINT1 WATCHPOINT2 ...]
+our $CMD = 'info watch';
+our $HELP = <<'HELP';
+=pod
+
+info watch [I<watchpoint1> I<watchpoint2> ...]
 
 List watch information. If watchpoints are specified, only information
 about them is shown. If no watchpoints are specified, show information
 about all watchpoints.
-EOH
+=cut
+HELP
 
 our $MIN_ABBREV = length('wa');
 our $SHORT_HELP = "Show watchpoint information";
@@ -38,7 +41,7 @@ our $SHORT_HELP = "Show watchpoint information";
 #     my $wpmgr = $proc->{dbgr}{watch};
 #     my @res = ();
 #     for my $bp ($wpmgr->list) {
-# 	push @res, "watch ${loc}";
+#       push @res, "watch ${loc}";
 #     }
 #     return @res;
 # }
@@ -53,10 +56,10 @@ sub wpprint($$;$)
     $proc->msg($mess);
 
     if ($wp->hits > 0) {
-    	my $ss = ($wp->hits > 1) ? 's' : '';
-    	my $msg = sprintf("\twatchpoint already hit %d time%s",
-    			  $wp->hits, $ss);
-    	$proc->msg($msg);
+        my $ss = ($wp->hits > 1) ? 's' : '';
+        my $msg = sprintf("\twatchpoint already hit %d time%s",
+                          $wp->hits, $ss);
+        $proc->msg($msg);
     }
 }
 
@@ -66,25 +69,25 @@ sub run($$) {
     my $watchmgr = $proc->{dbgr}{watch};
     my @args = @$args;
     if (scalar(@args) > 2) {
-    	shift @args; shift @args;
-    	for my $wp_name (@args) {
-    	    if ($watchmgr->find_by_name({$wp_name})) {
-		$self->wpprint($wp);
-    	    } else {
-    		$proc->msg("$wp_name is not a defined watchpoint");
-    	    }
-    	}
+        shift @args; shift @args;
+        for my $wp_name (@args) {
+            if ($watchmgr->find_by_name({$wp_name})) {
+                $self->wpprint($wp);
+            } else {
+                $proc->msg("$wp_name is not a defined watchpoint");
+            }
+        }
     } else {
-	my @watchpoints = $watchmgr->list;
-	if (scalar @watchpoints == 0) {
-	    $proc->msg("No watch expressions defined.");
-	} else {
-	    # There's at least one
-	    $proc->section("Num Type       Enb Expression");
-	    for my $wp (@watchpoints) { 
-		$self->wpprint($wp);
-	    }
-	}
+        my @watchpoints = $watchmgr->list;
+        if (scalar @watchpoints == 0) {
+            $proc->msg("No watch expressions defined.");
+        } else {
+            # There's at least one
+            $proc->section("Num Type       Enb Expression");
+            for my $wp (@watchpoints) { 
+                $self->wpprint($wp);
+            }
+        }
    }
 }
 
