@@ -14,7 +14,14 @@ use vars qw(@ISA @SUBCMD_VARS);
 use vars @Devel::Trepan::CmdProcessor::Command::Subsubcmd::SUBCMD_VARS;
 
 our $IN_LIST      = 1;
-our $HELP         = "Debug statement skipping";
+our $SHORT_HELP   = 'Debug statement skipping';
+our $HELP         = <<'HELP';
+=pod
+
+Debug statement skipping.
+=cut
+HELP
+
 our $MIN_ABBREV   = length('sk');
 use constant MAX_ARGS => 1;
  
