@@ -1,4 +1,4 @@
-# Copyright (C) 2011, 2012 Rocky Bernstein <rocky@cpan.org>
+# Copyright (C) 2011-2013 Rocky Bernstein <rocky@cpan.org>
 use strict;
 use Exporter;
 use warnings;
@@ -7,6 +7,19 @@ use rlib '../../..';
 # require_relative '../app/default'
 
 package Devel::Trepan::CmdProcessor;
+
+# Because we use Exporter we want to silence:
+#   Use of inherited AUTOLOAD for non-method ... is deprecated
+sub AUTOLOAD
+{
+    my $name = our $AUTOLOAD;
+    $name =~ s/.*:://;  # lose package name
+    my $target = "DynaLoader::$name";
+    goto &$target;
+}
+
+sub DESTROY{}
+
 use English qw( -no_match_vars );
 use Cwd 'abs_path';
 
@@ -37,14 +50,14 @@ sub canonic_file($$;$)
     return undef unless defined $filename;
     $resolve = 1 unless defined $resolve;
 
-    # For now we want resolved filenames 
+    # For now we want resolved filenames
     if ($self->{settings}{basename}) {
-        my $is_eval = DB::LineCache::filename_is_eval($filename);
+        my $is_eval = filename_is_eval($filename);
         return $is_eval ? $filename : (basename($filename) || $filename);
     } elsif ($resolve) {
-        my $mapped_filename = DB::LineCache::map_file($filename);
+        my $mapped_filename = map_file($filename);
         $filename = $mapped_filename if defined($mapped_filename);
-        my $is_eval = DB::LineCache::filename_is_eval($filename);
+        my $is_eval = filename_is_eval($filename);
         return $is_eval ? $filename : (abs_path($filename) || $filename);
     } else {
         return $filename;
@@ -58,20 +71,19 @@ sub min($$) {
 
 # Return the text to the current source line. We use trace line
 # information to try to retrieve all of the current source line up
-# to some limit of lines. The lines returned may be colorized. 
-# DB::LineCache actually does the retrieval.
+# to some limit of lines. The lines returned may be colorized.
+# Devel::Trepan::DB:LineCache::getline actually does the retrieval.
 sub current_source_text(;$)
 {
     my ($self, $opts) = @_;
     $opts = {max_continue => 5} unless defined $opts;
     my $filename    = $self->{frame}{file};
     my $line_number = $self->{frame}{line};
-    my $text        = (DB::LineCache::getline($filename, $line_number, $opts)) 
-        || '';
+    my $text        = (getline($filename, $line_number, $opts)) || '';
     chomp($text);
     return $text;
 }
-  
+
 sub resolve_file_with_dir($$)
 {
     my ($self, $path_suffix) = @_;
@@ -88,8 +100,8 @@ sub resolve_file_with_dir($$)
     }
     return undef;
 }
-  
-sub text_at($;$) 
+
+sub text_at($;$)
 {
     my ($self, $opts) = @_;
     $opts = {
@@ -100,26 +112,26 @@ sub text_at($;$)
     my $line_no = $self->line();
     my $text;
     my $filename = $self->filename();
-    if (DB::LineCache::filename_is_eval($filename)) {
+    if (filename_is_eval($filename)) {
         if ($DB::filename eq $filename) {
-            { 
+            {
                 # Some lines in @DB::line might not be defined.
                 # So we have to turn off strict here.
                 no warnings;
                 my $string = join("\n", @DB::dbline);
                 use warnings;
-                $filename = DB::LineCache::map_script($filename, $string);
-                $text = DB::LineCache::getline($filename, $line_no, $opts);
+                $filename = map_script($filename, $string);
+                $text = getline($filename, $line_no, $opts);
             }
         }
     } else {
         $text = line_at($filename, $line_no, $opts);
-        my ($map_file, $map_line) = 
-            DB::LineCache->map_file_line($filename, $line_no);
+        my ($map_file, $map_line) =
+            map_file_line($filename, $line_no);
     }
     $text;
   }
-  
+
 sub format_location($;$$$)
 {
     my ($self, $event, $frame, $frame_index) = @_;
@@ -133,7 +145,7 @@ sub format_location($;$$$)
     }
 
     $self->{line_no}  = $self->{frame}{line};
-    
+
     my $loc = $self->source_location_info;
     my $suffix = ($event eq 'return' && defined($DB::_[0])) ? " $DB::_[0]" : '';
     my $pkg = $self->{frame}{pkg} || '??' ;
@@ -155,7 +167,7 @@ sub print_location($;$)
         $self->msg($text, {unlimited => 1});
     }
   }
-  
+
 sub source_location_info($)
 {
     my $self = shift;
@@ -170,24 +182,37 @@ sub source_location_info($)
     if ($self->{settings}{displayop} && $DB::OP_addr) {
         $op_addr = sprintf " \@0x%x", $DB::OP_addr;
     }
-    if (DB::LineCache::filename_is_eval($filename)) {
+    if (filename_is_eval($filename)) {
+	### FIXME: put this all into DB::LineCache
         if ($DB::filename eq $filename) {
             # Some lines in @DB::line might not be defined.
-            # So we have to turn off strict here. 
+            # So we have to turn off strict here.
             if ($filename ne '-e') {
-                no warnings;
-                my $string = join('', @DB::dbline);
-                use warnings;
-                $filename = DB::LineCache::map_script($filename, $string);
+		my $string = undef;
+		if (@DB::dbline) {
+		    no warnings;
+		    $string = join('', @DB::dbline);
+		    use warnings;
+		} elsif ($filename =~/^sub (\S+)/) {
+		    my $func = $1;
+		    if (%SelfLoader::Cache) {
+			$string = $SelfLoader::Cache{$func};
+			$string =~ s/^\n#line 1.+\n//;
+		    }
+		}
+		unless (defined($string)) {
+		    return "${filename}:${line_number}$op_addr";
+		}
+                my $try_filename = map_script($filename, $string);
+		$filename = $try_filename if defined($try_filename);
             }
-            $canonic_filename = $self->canonic_file($self->filename(), 0);
-            return "${canonic_filename}:${line_number} " . 
-                "remapped $filename:$line_number$op_addr";
+            return $self->filename() .
+                " remapped $filename:$line_number$op_addr";
         }
     }
     $canonic_filename = $self->canonic_file($self->filename(), 0);
     return "${canonic_filename}:${line_number}$op_addr";
-} 
+}
 
 unless (caller()) {
     # Demo it.
